@@ -2,7 +2,7 @@ package App::perlbrew;
 use strict;
 use warnings;
 use 5.008;
-our $VERSION = "0.66";
+our $VERSION = "0.71";
 use Config;
 
 BEGIN {
@@ -12,7 +12,7 @@ BEGIN {
     @INC = (
         $Config{sitelibexp}."/".$Config{archname},
         $Config{sitelibexp},
-        @Config{qw<archlibexp privlibexp>},
+        @Config{qw<vendorlibexp vendorarchexp archlibexp privlibexp>},
     );
 
     require Cwd;
@@ -22,8 +22,17 @@ BEGIN {
 use List::Util qw/min/;
 use Getopt::Long ();
 
+sub uniq {
+    my %seen; grep { !$seen{$_}++ } @_;
+}
+
 ### global variables
 
+# set $ENV{SHELL} to executable path of parent process (= shell) if it's missing
+# (e.g. if this script was executed by a daemon started with "service xxx start")
+# ref: https://github.com/gugod/App-perlbrew/pull/404
+$ENV{SHELL} ||= readlink joinpath("/proc", getppid, "exe") if -d "/proc";
+
 local $SIG{__DIE__} = sub {
     my $message = shift;
     warn $message;
@@ -111,36 +120,47 @@ sub files_are_the_same {
     my %commands = (
         curl => {
             test     => '--version >/dev/null 2>&1',
-            get      => '--silent --location --fail -o - {url}',
-            download => '--silent --location --fail -o {output} {url}'
+            get      => '--insecure --silent --location --fail -o - {url}',
+            download => '--insecure --silent --location --fail -o {output} {url}',
+            order    => 1,
         },
         wget => {
             test     => '--version >/dev/null 2>&1',
-            get      => '--quiet -O - {url}',
-            download => '--quiet -O {output} {url}',
+            get      => '--no-check-certificate --quiet -O - {url}',
+            download => '--no-check-certificate --quiet -O {output} {url}',
+            order    => 2,
         },
         fetch => {
             test     => '--version >/dev/null 2>&1',
-            get      => '-o - {url}',
-            download => '{url}'
+            get      => '--no-verify-peer -o - {url}',
+            download => '--no-verify-peer {url}',
+            order    => 3,
         }
     );
 
+    our $HTTP_USER_AGENT_PROGRAM;
     sub http_user_agent_program {
-        my $program;
-        for my $p (keys %commands) {
-            my $code = system("$p $commands{$p}->{test}") >> 8;
-            if ($code != 127) {
-                $program = $p;
-                last;
+        $HTTP_USER_AGENT_PROGRAM ||= do {
+            my $program;
+
+            for my $p (sort {$commands{$a}{order}<=>$commands{$b}{order}} keys %commands) {
+                my $code = system("$p $commands{$p}->{test}") >> 8;
+                if ($code != 127) {
+                    $program = $p;
+                    last;
+                }
             }
-        }
 
-        unless($program) {
-            die "[ERROR] Cannot find a proper http user agent program. Please install curl or wget.\n";
-        }
+            unless($program) {
+                die "[ERROR] Cannot find a proper http user agent program. Please install curl or wget.\n";
+            }
 
-        return $program;
+            $program;
+        };
+
+        die "[ERROR] Unrecognized http user agent program: $HTTP_USER_AGENT_PROGRAM. It can only be one of: ".join(",", keys %commands)."\n" unless $commands{$HTTP_USER_AGENT_PROGRAM};
+
+        return $HTTP_USER_AGENT_PROGRAM;
     }
 
     sub http_user_agent_command {
@@ -245,6 +265,7 @@ sub new {
 
     my %opt = (
         original_argv  => \@argv,
+        args => [],
         force => 0,
         quiet => 0,
         D => [],
@@ -259,25 +280,27 @@ sub new {
 
     $opt{$_} = '' for keys %flavor;
 
-    # build a local @ARGV to allow us to use an older
-    # Getopt::Long API in case we are building on an older system
-    local (@ARGV) = @argv;
+    if (@argv) {
+        # build a local @ARGV to allow us to use an older
+        # Getopt::Long API in case we are building on an older system
+        local (@ARGV) = @argv;
 
-    Getopt::Long::Configure(
-        'pass_through',
-        'no_ignore_case',
-        'bundling',
-        'permute',                       # default behaviour except 'exec'
-    );
+        Getopt::Long::Configure(
+            'pass_through',
+            'no_ignore_case',
+            'bundling',
+            'permute',          # default behaviour except 'exec'
+        );
 
-    $class->parse_cmdline (\%opt);
+        $class->parse_cmdline(\%opt);
 
-    $opt{args} = \@ARGV;
+        $opt{args} = \@ARGV;
 
-    # fix up the effect of 'bundling'
-    foreach my $flags (@opt{qw(D U A)}) {
-        foreach my $value(@{$flags}) {
-            $value =~ s/^=//;
+        # fix up the effect of 'bundling'
+        foreach my $flags (@opt{qw(D U A)}) {
+            foreach my $value (@{$flags}) {
+                $value =~ s/^=//;
+            }
         }
     }
 
@@ -289,7 +312,7 @@ sub parse_cmdline {
 
     my @f = map { $flavor{$_}{opt} || $_ } keys %flavor;
 
-    Getopt::Long::GetOptions(
+    return Getopt::Long::GetOptions(
         $params,
 
         'force|f!',
@@ -297,7 +320,7 @@ sub parse_cmdline {
         'quiet|q!',
         'verbose|v',
         'as=s',
-	'append=s',
+      	'append=s',
         'help|h',
         'version',
         'root=s',
@@ -322,7 +345,6 @@ sub parse_cmdline {
 
         @ext
     )
-      or run_command_help(1);
 }
 
 sub root {
@@ -347,11 +369,6 @@ sub current_lib {
     return $self->{current_lib} || $self->env('PERLBREW_LIB')  || '';
 }
 
-sub current_perl_executable {
-    my ($self) = @_;
-    return $self->installed_perl_executable($self->current_perl);
-}
-
 sub current_env {
     my ($self) = @_;
     my $l = $self->current_lib;
@@ -733,6 +750,7 @@ sub run_command_init {
          ["csh_wrapper", "CSH_WRAPPER_CONTENT"],
          ["csh_set_path", "CSH_SET_PATH_CONTENT"],
          ["perlbrew-completion.bash", "BASH_COMPLETION_CONTENT"],
+         ["perlbrew.fish", "PERLBREW_FISH_CONTENT" ],
      ) {
         my ($file_name, $method) = @$_;
         my $path = joinpath($etc_dir, $file_name);
@@ -762,6 +780,10 @@ sub run_command_init {
         $shrc = "bashrc";
         $yourshrc = 'zshenv';
     }
+    elsif( $self->env('SHELL') =~ m/fish/ ) {
+        $shrc = "perlbrew.fish";
+        $yourshrc = 'config/fish/config.fish';
+    }
     else {
         $shrc = "bashrc";
         $yourshrc = "bash_profile";
@@ -775,6 +797,11 @@ sub run_command_init {
         $code = "    export PERLBREW_HOME=$pb_home_dir\n" . $code;
     }
 
+    if ( $self->env('SHELL') =~ m/fish/ ) {
+        $code =~ s/source/./;
+        $code =~ s/export (\S+)=(\S+)/set -x $1 $2/;
+    }
+
     print <<INSTRUCTION;
 
 perlbrew root ($root_dir) is initialized.
@@ -975,7 +1002,7 @@ sub do_install_release {
     my $dist_tarball_path = joinpath($self->root, "dists", $dist_tarball);
 
     if (-f $dist_tarball_path) {
-        print "Use the previously fetched ${dist_tarball}\n"
+        print "Using the previously fetched ${dist_tarball}\n"
             if $self->{verbose};
     }
     else {
@@ -1143,6 +1170,9 @@ sub run_command_install_multiple {
 sub run_command_download {
     my ($self, $dist) = @_;
 
+    $dist = $self->resolve_stable_version
+        if $dist && $dist eq 'stable';
+
     my ($dist_version) = $dist =~ /^ (?:perl-?)? (.*) $/xs;
 
     die "\"$dist\" does not look like a perl distribution name. " unless $dist_version =~ /^\d\./;
@@ -1272,7 +1302,7 @@ sub do_install_this {
     }
 
     unshift @d_options, qq(prefix=$perlpath);
-    push @d_options, "usedevel" if $dist_version =~ /5\.1[13579]|git|blead/;
+    push @d_options, "usedevel" if $dist_version =~ /5\.\d[13579]|git|blead/;
 
     unless (grep { /eval:scriptdir=/} @a_options) {
         push @a_options, "'eval:scriptdir=${perlpath}/bin'";
@@ -1460,7 +1490,21 @@ sub installed_perls {
     for (<$root/perls/*>) {
         my ($name) = $_ =~ m/\/([^\/]+$)/;
         my $executable = joinpath($_, 'bin', 'perl');
-        my $orig_version = `$executable -e 'print \$]'`;
+        my $version_file = joinpath($_,'.version');
+        my $orig_version;
+        if ( -e $version_file ){
+            open my $fh, '<', $version_file;
+            local $/;
+            $orig_version = <$fh>;
+            chomp $orig_version;
+        } else {
+            $orig_version = `$executable -e 'print \$]'`;
+            if ( defined $orig_version and length $orig_version ){
+                if (open my $fh, '>', $version_file ){
+                    print {$fh} $orig_version;
+		}
+            }
+        }
 
         push @result, {
             name        => $name,
@@ -1531,6 +1575,14 @@ sub perlbrew_env {
         PERLBREW_ROOT => $self->root
     );
 
+    require local::lib;
+    my $current_local_lib_root = $self->env("PERL_LOCAL_LIB_ROOT") || "";
+    my $current_local_lib_context = local::lib->new;
+    my @perlbrew_local_lib_root =  uniq(grep { /\Q${PERLBREW_HOME}\E/ } split(/:/, $current_local_lib_root));
+    if ($current_local_lib_root =~ /^\Q$PERLBREW_HOME\E/) {
+        $current_local_lib_context = $current_local_lib_context->activate($_) for @perlbrew_local_lib_root;
+    }
+
     if ($perl_name) {
         if(-d  "@{[ $self->root ]}/perls/$perl_name/bin") {
             $env{PERLBREW_PERL}    = $perl_name;
@@ -1539,63 +1591,35 @@ sub perlbrew_env {
         }
 
         if ($lib_name) {
-            require local::lib;
-
-            if ($ENV{PERL_LOCAL_LIB_ROOT}
-                && $ENV{PERL_LOCAL_LIB_ROOT} =~ /^\Q$PERLBREW_HOME\E/
-            ) {
-                my %deactivate_env = local::lib->build_deact_all_environment_vars_for($ENV{PERL_LOCAL_LIB_ROOT});
-                @env{keys %deactivate_env} = values %deactivate_env;
-            }
+            $current_local_lib_context = $current_local_lib_context->deactivate($_) for @perlbrew_local_lib_root;
 
             my $base = "$PERLBREW_HOME/libs/${perl_name}\@${lib_name}";
 
             if (-d $base) {
-                delete $ENV{PERL_LOCAL_LIB_ROOT};
-                @ENV{keys %env} = values %env;
-                while (my ($k,$v) = each %ENV) {
-                    delete $ENV{$k} unless defined($v);
-                }
-                my %lib_env = local::lib->build_environment_vars_for($base, 0, 1);
+                $current_local_lib_context = $current_local_lib_context->activate($base);
                 $env{PERLBREW_PATH}    = joinpath($base, "bin") . ":" . $env{PERLBREW_PATH};
                 $env{PERLBREW_MANPATH} = joinpath($base, "man") . ":" . $env{PERLBREW_MANPATH};
                 $env{PERLBREW_LIB}  = $lib_name;
-
-                $env{PERL_MM_OPT}   = $lib_env{PERL_MM_OPT};
-                $env{PERL_MB_OPT}   = $lib_env{PERL_MB_OPT};
-                $env{PERL5LIB}      = $lib_env{PERL5LIB};
-                $env{PERL_LOCAL_LIB_ROOT} = $lib_env{PERL_LOCAL_LIB_ROOT};
             }
-        }
-        else {
-            my $libroot = $self->env("PERL_LOCAL_LIB_ROOT");
-            if ($libroot && $libroot =~ /^\Q$PERLBREW_HOME\E/) {
-                require local::lib;
-                my %deactivate_env = local::lib->build_deact_all_environment_vars_for($libroot);
-                @env{keys %deactivate_env} = values %deactivate_env;
-                $env{PERLBREW_LIB}  = undef;
-            }
-            if (my $perl5lib = $self->env("PERL5LIB")) {
-                my @perl5libs = split $Config{path_sep} => $perl5lib;
-                my @pristine_perl5libs = grep { !/^\Q$PERLBREW_HOME\E/ } @perl5libs;
-                if (@pristine_perl5libs) {
-                    $env{PERL5LIB} = join $Config{path_sep}, @pristine_perl5libs;
-                }
-                else {
-                    $env{PERL5LIB} = undef;
-                }
-            }
-        }
-    }
-    else {
-        my $libroot = $self->env("PERL_LOCAL_LIB_ROOT");
-        if ($libroot && $libroot =~ /^\Q$PERLBREW_HOME\E/) {
-            require local::lib;
-            my %deactivate_env = local::lib->build_deact_all_environment_vars_for($libroot);
-            @env{keys %deactivate_env} = values %deactivate_env;
-            $env{PERLBREW_LIB}  = undef;
+        } else {
+            $current_local_lib_context = $current_local_lib_context->deactivate($_) for @perlbrew_local_lib_root;
+            $env{PERLBREW_LIB} = undef;
         }
 
+        my %ll_env = $current_local_lib_context->build_environment_vars;
+        delete $ll_env{PATH};
+        for my $key (keys %ll_env) {
+            $env{$key} = $ll_env{$key};
+        }
+    } else {
+        $current_local_lib_context = $current_local_lib_context->deactivate($_) for @perlbrew_local_lib_root;
+
+        my %ll_env = $current_local_lib_context->build_environment_vars;
+        delete $ll_env{PATH};
+        for my $key (keys %ll_env) {
+            $env{$key} = $ll_env{$key};
+        }
+        $env{PERLBREW_LIB} = undef;
         $env{PERLBREW_PERL} = undef;
     }
 
@@ -1819,11 +1843,15 @@ sub run_command_env {
         for my $k (sort keys %env) {
             my $v = $env{$k};
             if (defined $v) {
-                $v =~ s/(\\")/\\$1/g;
-                print "export $k=\"$v\"\n";
+                if ($v || ($v && exists($ENV{$k}))) {
+                    $v =~ s/(\\")/\\$1/g;
+                    print "export $k=\"$v\"\n";
+                }
             }
             else {
-                print "unset $k\n";
+                if (exists $ENV{$k}) {
+                    print "unset $k\n";
+                }
             }
         }
     }
@@ -1831,11 +1859,15 @@ sub run_command_env {
         for my $k (sort keys %env) {
             my $v = $env{$k};
             if (defined $v) {
-                $v =~ s/(\\")/\\$1/g;
-                print "setenv $k \"$v\"\n";
+                if ($v || ($v && exists($ENV{$k}))) {
+                    $v =~ s/(\\")/\\$1/g;
+                    print "setenv $k \"$v\"\n";
+                }
             }
             else {
-                print "unsetenv $k\n";
+                if (exists $ENV{$k}) {
+                    print "unsetenv $k\n";
+                }
             }
         }
     }
@@ -1860,7 +1892,7 @@ sub run_command_symlink_executables {
 sub run_command_install_patchperl {
     my ($self) = @_;
     $self->do_install_program_from_url(
-        'https://raw.github.com/gugod/patchperl-packing/master/patchperl',
+        'https://raw.githubusercontent.com/gugod/patchperl-packing/master/patchperl',
         'patchperl',
         sub {
             my ($body) = @_;
@@ -1872,7 +1904,7 @@ sub run_command_install_patchperl {
 
 sub run_command_install_cpanm {
     my ($self) = @_;
-    $self->do_install_program_from_url('https://raw.github.com/miyagawa/cpanminus/master/cpanm' => 'cpanm');
+    $self->do_install_program_from_url('https://raw.githubusercontent.com/miyagawa/cpanminus/master/cpanm' => 'cpanm');
 }
 
 sub run_command_self_upgrade {
@@ -2164,9 +2196,6 @@ sub run_command_lib_delete {
 
     my ($perl_name, $lib_name) = $self->resolve_installation_name($name);
 
-    if (!$perl_name) {
-    }
-
     my $fullname = $perl_name . '@' . $lib_name;
 
     my $current  = $self->current_perl . '@' . ($self->env("PERLBREW_LIB") || "");
@@ -2295,18 +2324,18 @@ sub resolve_installation_name {
 
 sub format_info_output
 {
-    my ($self) = @_;
+    my ($self, $module) = @_;
 
     my $out = '';
 
     $out .= "Current perl:\n";
     if ($self->current_perl) {
         $out .= "  Name: " . $self->current_env . "\n";
-        $out .= "  Path: " . $self->current_perl_executable . "\n";
+        $out .= "  Path: " . $self->installed_perl_executable($self->current_perl) . "\n";
         $out .= "  Config: " . $self->configure_args( $self->current_perl ) . "\n";
         $out .= join('', "  Compiled at: ", (map {
             /  Compiled at (.+)\n/ ? $1 : ()
-        } `@{[ $self->current_perl_executable ]} -V`), "\n");
+        } `@{[ $self->installed_perl_executable($self->current_perl) ]} -V`), "\n");
     }
     else {
         $out .= "Using system perl." . "\n";
@@ -2319,12 +2348,18 @@ sub format_info_output
     for(map{"PERLBREW_$_"}qw(ROOT HOME PATH MANPATH)) {
         $out .= "    $_: " . ($self->env($_)||"") . "\n";
     }
+
+    if ( $module ) {
+        my $code = qq{eval "require $module" and do { (my \$f = "$module") =~ s<::></>g; \$f .= ".pm"; print "$module\n  Location: \$INC{\$f}\n  Version: " . ($module->VERSION ? $module->VERSION : "no VERSION specified" ) } or do { print "$module could not be found, is it installed?" } };
+        $out .= "\nModule: ".$self->do_capture( $self->installed_perl_executable($self->current_perl), "-le", $code );
+    }
+
     $out;
 }
 
 sub run_command_info {
-    my ($self) = @_;
-    print $self->format_info_output;
+    my ($self) = shift;
+    print $self->format_info_output(@_);
 }
 
 
@@ -2371,7 +2406,7 @@ sub _load_config {
 }
 
 sub BASHRC_CONTENT() {
-    return "export PERLBREW_BASHRC_VERSION=$VERSION\n\n" . <<'RC';
+    return "export PERLBREW_BASHRC_VERSION=$VERSION\n\n" . sprintf <<'RC', $PERLBREW_ROOT;
 
 __perlbrew_reinit() {
     if [[ ! -d "$PERLBREW_HOME" ]]; then
@@ -2497,7 +2532,7 @@ perlbrew () {
     return ${exit_status:-0}
 }
 
-[[ -z "$PERLBREW_ROOT" ]] && export PERLBREW_ROOT="$HOME/perl5/perlbrew"
+[[ -z "$PERLBREW_ROOT" ]] && export PERLBREW_ROOT="%s"
 [[ -z "$PERLBREW_HOME" ]] && export PERLBREW_HOME="$HOME/.perlbrew"
 
 if [[ ! -n "$PERLBREW_SKIP_INIT" ]]; then
@@ -2535,6 +2570,176 @@ complete -F _perlbrew_compgen perlbrew
 COMPLETION
 }
 
+sub PERLBREW_FISH_CONTENT {
+    return "set -x PERLBREW_FISH_VERSION $VERSION\n" . <<'END';
+
+function __perlbrew_reinit
+    if not test -d "$PERLBREW_HOME"
+        mkdir -p "$PERLBREW_HOME"
+    end
+
+    echo '# DO NOT EDIT THIS FILE' > "$PERLBREW_HOME/init"
+    command perlbrew env $argv[1] | \grep PERLBREW_ >> "$PERLBREW_HOME/init"
+    __source_init
+    __perlbrew_set_path
+end
+
+function __perlbrew_set_path
+    set -l MANPATH_WITHOUT_PERLBREW (perl -e 'print join " ", grep { index($_, $ENV{PERLBREW_HOME}) < 0 } grep { index($_, $ENV{PERLBREW_ROOT}) < 0 } split/:/,qx(manpath 2> /dev/null);')
+
+    if test -n "$PERLBREW_MANPATH"
+        set -x MANPATH $PERLBREW_MANPATH $MANPATH_WITHOUT_PERLBREW
+    else
+        set -x MANPATH $MANPATH_WITHOUT_PERLBREW
+    end
+
+    set -l PATH_WITHOUT_PERLBREW (eval $perlbrew_command display-pristine-path | perl -pe'y/:/ /')
+
+    if test -n "$PERLBREW_PATH"
+        set -x PERLBREW_PATH (echo $PERLBREW_PATH | perl -pe 'y/:/ /' )
+        eval set -x PATH $PERLBREW_PATH $PATH_WITHOUT_PERLBREW
+    else
+        eval set -x PATH $PERLBREW_ROOT/bin $PATH_WITHOUT_PERLBREW
+    end
+end
+
+function __perlbrew_set_env
+    set -l code (eval $perlbrew_command env $argv | perl -pe 's/export\s+(\S+)="(\S*)"/set -x $1 $2;/g; y/:/ /')
+
+    if test -z "$code"
+        return 0;
+    else
+        eval $code
+    end
+end
+
+function __perlbrew_activate
+    functions -e perl
+
+    if test -n "$PERLBREW_PERL"
+        if test -z "$PERLBREW_LIB"
+            __perlbrew_set_env $PERLBREW_PERL
+        else
+            __perlbrew_set_env $PERLBREW_PERL@$PERLBREW_LIB
+        end
+    end
+
+    __perlbrew_set_path
+end
+
+function __perlbrew_deactivate
+    __perlbrew_set_env
+    set -x PERLBREW_PERL
+    set -x PERLBREW_LIB
+    set -x PERLBREW_PATH
+    __perlbrew_set_path
+end
+
+function perlbrew
+
+    test -z "$argv"
+    and echo "    Usage: perlbrew <command> [options] [arguments]"
+    and echo "       or: perlbrew help"
+    and return 1
+
+    switch $argv[1]
+        case use
+            if test ( count $argv ) -eq 1
+                if test -z "$PERLBREW_PERL"
+                    echo "Currently using system perl"
+                else
+                    echo "Currently using $PERLBREW_PERL"
+                end
+            else
+                __perlbrew_set_env $argv[2]
+                if test "$status" -eq 0
+                    __perlbrew_set_path
+                end
+            end
+
+        case switch
+            if test ( count $argv ) -eq 1
+                command perlbrew switch
+            else
+                perlbrew use $argv[2]
+                if test "$status" -eq 0
+                    __perlbrew_reinit $argv[2]
+                end
+            end
+
+        case off
+            __perlbrew_deactivate
+            echo "perlbrew is turned off."
+
+        case switch-off
+            __perlbrew_deactivate
+            __perlbrew_reinit
+            echo "perlbrew is switched off."
+
+        case '*'
+            command perlbrew $argv
+    end
+end
+
+function __source_init
+    perl -pe's/^export/set -x/; s/=/ /; s/$/;/;' "$PERLBREW_HOME/init" | . -
+end
+
+if test -z "$PERLBREW_ROOT"
+    set -x PERLBREW_ROOT "$HOME/perl5/perlbrew"
+end
+
+if test -z "$PERLBREW_HOME"
+    set -x PERLBREW_HOME "$HOME/.perlbrew"
+end
+
+if test -z "$PERLBREW_SKIP_INIT" -a -f "$PERLBREW_HOME/init"
+    __source_init
+end
+
+set perlbrew_bin_path "$PERLBREW_ROOT/bin"
+
+if test -f "$perlbrew_bin_path/perlbrew"
+    set perlbrew_command "$perlbrew_bin_path/perlbrew"
+else
+    set perlbrew_command perlbrew
+end
+
+set -e perlbrew_bin_path
+
+__perlbrew_activate
+
+## autocomplete stuff #############################################
+
+function __fish_perlbrew_needs_command
+  set cmd (commandline -opc)
+  if test (count $cmd) -eq 1 -a $cmd[1] = 'perlbrew'
+    return 0
+  end
+  return 1
+end
+
+function __fish_perlbrew_using_command
+  set cmd (commandline -opc)
+  if test (count $cmd) -gt 1
+    if [ $argv[1] = $cmd[2] ]
+      return 0
+    end
+  end
+end
+
+for com in (perlbrew help | perl -ne'print lc if s/^COMMAND:\s+//')
+    complete -f -c perlbrew -n '__fish_perlbrew_needs_command' -a $com
+end
+
+for com in switch use;
+    complete -f -c perlbrew -n "__fish_perlbrew_using_command $com" \
+        -a '(perlbrew list | perl -pe\'s/\*?\s*(\S+).*/$1/\')'
+end
+
+END
+}
+
 sub CSH_WRAPPER_CONTENT {
     return <<'WRAPPER';
 set perlbrew_exit_status=0
@@ -2716,16 +2921,15 @@ App::perlbrew - Manage perl installations in your $HOME
     perlbrew available
 
     # Install some Perls
-    perlbrew install 5.14.0
+    perlbrew install 5.18.2
     perlbrew install perl-5.8.1
-    perlbrew install perl-5.13.6
+    perlbrew install perl-5.19.9
 
     # See what were installed
     perlbrew list
 
-    # Switch perl in the $PATH
-    perlbrew switch perl-5.12.2
-    perl -v
+    # Swith to an installation and set it as default
+    perlbrew switch perl-5.18.2
 
     # Temporarily use another version only in current shell.
     perlbrew use perl-5.8.1
@@ -2744,11 +2948,13 @@ App::perlbrew - Manage perl installations in your $HOME
 =head1 DESCRIPTION
 
 perlbrew is a program to automate the building and installation of perl in an
-easy way. It installs everything to C<~/perl5/perlbrew>, and requires you to
-tweak your PATH by including a bashrc/cshrc file it provides. You then can
-benefit from not having to run 'sudo' commands to install cpan modules because
-those are installed inside your HOME too. It provides multiple isolated perl
-environments, and a mechanism for you to switch between them.
+easy way. It provides multiple isolated perl environments, and a mechanism
+for you to switch between them.
+
+Everything are installed unter C<~/perl5/perlbrew>. You then need to include a
+bashrc/cshrc provided by perlbrew to tweak the PATH for you. You then can
+benefit from not having to run 'sudo' commands to install
+cpan modules because those are installed inside your HOME too.
 
 For the documentation of perlbrew usage see L<perlbrew> command
 on CPAN, or by running C<perlbrew help>. The following documentation
@@ -2774,8 +2980,8 @@ The installed perlbrew command is a standalone executable that can be run with
 system perl. The minimum system perl version requirement is 5.8.0, which should
 be good enough for most of the OSes these days.
 
-A packed version of C<patchperl> to C<~/perl5/perlbrew/bin>, which is required
-to build old perls.
+A fat-packed version of C<patchperl> is also installed to
+C<~/perl5/perlbrew/bin>, which is required to build old perls.
 
 The directory C<~/perl5/perlbrew> will contain all install perl executables,
 libraries, documentations, lib, site_libs. In the documentation, that directory
@@ -2786,6 +2992,10 @@ environment variable before running the installer:
     export PERLBREW_ROOT=/opt/perl5
     curl -kL http://install.perlbrew.pl | bash
 
+As a result, different users on the same machine can all share the same perlbrew
+root directory (although only original user that made the installation would
+have the permission to perform perl installations.)
+
 You may also install perlbrew from CPAN:
 
     cpan App::perlbrew
@@ -2841,7 +3051,7 @@ Kang-min Liu  C<< <gugod@gugod.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2010, 2011, 2012 Kang-min Liu C<< <gugod@gugod.org> >>.
+Copyright (c) 2010,2011,2012,2013,2014 Kang-min Liu C<< <gugod@gugod.org> >>.
 
 =head1 LICENCE
 
